==> foundation-1.0.2.tgz: package/lib/esm/Text.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsx, css } from "@emotion/react";
import useTheme from "./useTheme";
import { omit, pick } from "lodash";
import { createContext, useContext } from "react";
import useSs from "./useSs";
import { createStyleObject } from "@capsizecss/core";
var ssProps = ["bg", "radius"];
var weights = {
    ultraBlack: 900,
    black: 800,
    bold: 700,
    semiBold: 600,
    medium: 500,
    regular: 400,
    light: 300,
    thin: 200,
    ultraThin: 100,
};
var textContext = createContext({});
var Provider = textContext.Provider;
export var TextProvider = function (_a) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return (_jsx(Provider, __assign({ value: props }, { children: children })));
};
export default (function (props) {
    var _a, _b, _c, _d;
    var _e = useTheme(), color = _e.color, fontSize = _e.fontSize, defaultFont = _e.defaultFont, fonts = _e.fonts;
    var ss = useSs(pick(props, ssProps));
    var contextProps = useContext(textContext);
    props = __assign(__assign({}, contextProps), props);
    var weight = props.weight, headingLevel = props.headingLevel;
    var font = fonts[(_a = props.font) !== null && _a !== void 0 ? _a : defaultFont];
    var size = (_b = props.size) !== null && _b !== void 0 ? _b : "md";
    if (!props.children)
        return null;
    return jsx((_c = props.as) !== null && _c !== void 0 ? _c : (headingLevel ? "h".concat(headingLevel) : "p"), __assign(__assign({}, omit(props, ssProps)), { css: css(__assign(__assign(__assign({}, ss), { fontFamily: font.name, display: "block", margin: 0, fontWeight: weight && weights[weight], textAlign: props.align, textDecoration: props.underline ? "underline" : undefined, color: color((_d = props.color) !== null && _d !== void 0 ? _d : "text").hex }), createStyleObject({
            capHeight: fontSize(size).raw,
            lineGap: fontSize(size).raw,
            fontMetrics: font.metrics,
        }))) }));
});

==> foundation-2.3.0.tgz: package/lib/esm/Text.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsx, useTheme, css } from "@emotion/react";
import { omit, pick } from "lodash";
import { createContext, useContext } from "react";
import useSs from "./useSs";
import { createStyleObject } from "@capsizecss/core";
var ssProps = ["bg", "radius"];
var weights = {
    ultraBlack: 900,
    black: 800,
    bold: 700,
    semiBold: 600,
    medium: 500,
    regular: 400,
    light: 300,
    thin: 200,
    ultraThin: 100,
};
var textContext = createContext({});
var Provider = textContext.Provider;
export var TextProvider = function (_a) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return (_jsx(Provider, __assign({ value: props }, { children: children })));
};
export default (function (props) {
    var _a, _b, _c, _d;
    var _e = useTheme(), color = _e.color, fontSize = _e.fontSize, defaultFont = _e.defaultFont, fonts = _e.fonts;
    var ss = useSs(pick(props, ssProps));
    var contextProps = useContext(textContext);
    props = __assign(__assign({}, contextProps), props);
    var weight = props.weight, headingLevel = props.headingLevel;
    var font = fonts[(_a = props.font) !== null && _a !== void 0 ? _a : defaultFont];
    var size = (_b = props.size) !== null && _b !== void 0 ? _b : "md";
    if (!props.children)
        return null;
    return jsx((_c = props.as) !== null && _c !== void 0 ? _c : (headingLevel ? "h".concat(headingLevel) : "p"), __assign(__assign({}, omit(props, ssProps)), { css: css(__assign(__assign(__assign({}, ss), { fontFamily: font.name, display: "block", margin: 0, fontWeight: weight && weights[weight], textAlign: props.align, textDecoration: props.underline ? "underline" : undefined, color: color((_d = props.color) !== null && _d !== void 0 ? _d : "text").hex }), createStyleObject({
            capHeight: fontSize(size).raw,
            lineGap: fontSize(size).raw,
            fontMetrics: font.metrics,
        }))) }));
});
